@@ -28,6 +28,7 @@
 #include <QtCore/QFile>
 #include <QtCore/QDir>
 #include <QtCore/QDateTime>
+#include <QtGui/QDesktopServices>
 
 #include <QtXml/QXmlStreamReader>
 
@@ -48,6 +49,8 @@ Car2goEngine::Car2goEngine(const QString &cacheDir) :
         qDebug() << "cachedir for car2go doesnt exist... creating" << m_cacheDir;
         cacheDirectory.mkpath(m_cacheDir);
     }
+
+    connect(this, SIGNAL(locationChanged()), SLOT(loadBusinessArea()));
 }
 
 QStringList Car2goEngine::supportedLocations()
@@ -181,6 +184,11 @@ QGeoBoundingBox Car2goEngine::startingBounds()
     }
 }
 
+GMWBusinessArea Car2goEngine::businessArea()
+{
+    return m_businessArea;
+}
+
 void Car2goEngine::receivedData(QNetworkReply *reply)
 {
     //qDebug() << "Reply received: " << reply->request().url();
@@ -192,7 +200,7 @@ void Car2goEngine::receivedData(QNetworkReply *reply)
             qDebug() << reply->request().url() << "aborted";
         }
         m_downloads.clear();
-        emit downloadFinished(false, reply->errorString());
+        emit downloadFinished(GMWItem::TypeUnknown, false, reply->errorString());
         return;
     }
 
@@ -407,13 +415,28 @@ void Car2goEngine::parse(NetworkReplyType type, const QString &xmlData)
         emit objectsReceived(parsedItems);
     }
 
+    GMWItem::Type itemType = GMWItem::TypeUnknown;
+    switch(type) {
+    case ParkingSpotsReply:
+        itemType = GMWItem::TypeParkingLot;
+        break;
+    case GasStationReply:
+        itemType = GMWItem::TypeGasStation;
+        break;
+    case VehiclesReply:
+        itemType = GMWItem::TypeVehicle;
+        break;
+    case IconReply:
+        itemType = GMWItem::TypeUnknown;
+    }
+
     if (xml.hasError()) {
         qDebug() << "Xml has errors!";
-        emit downloadFinished(false, tr("Downloaded Data contains errors"));
+        emit downloadFinished(itemType, false, tr("Downloaded Data contains errors"));
     } else {
         // Emit the finished signal only if this is the last download in progress.
         if (m_downloads.size() == 0) {
-            emit downloadFinished(true, "");
+            emit downloadFinished(itemType, true, "");
         }
     }
 }
@@ -428,3 +451,70 @@ bool Car2goEngine::hasDownloadError() const
     }
     return false;
 }
+
+void Car2goEngine::loadBusinessArea()
+{
+    qDebug() << "****************************** loading business area";
+#ifdef Q_WS_MAEMO_5
+    QFile file("/opt/usr/share/getmewheels/data/" + location() + ".gpx");
+#else
+    QFile file("data/" + location() + ".gpx");
+#endif
+    file.open(QIODevice::ReadOnly);
+    QXmlStreamReader xml(&file);
+
+    QList<Area> areaList;
+    QList<Area> excludeList;
+    while(!xml.atEnd()) {
+        xml.readNext();
+//        qDebug() << xml.tokenString() << " " << xml.name();
+
+        // Track
+        if (xml.name() == "trk") {
+            xml.readNext();
+
+            QList<QGeoCoordinate> path;
+
+            bool exclude = false;
+            while(!(xml.tokenType() == QXmlStreamReader::EndElement && xml.name() == "trk")) {
+                  xml.readNext();
+//                  qDebug() << xml.tokenString() << " " << xml.name();
+                  if(xml.tokenType() == QXmlStreamReader::StartElement && xml.name() == "name") {
+                      xml.readNext();
+                      qDebug() << "got track" << xml.text();
+                      if(xml.text().toString().startsWith("Exclude_")) {
+                          exclude = true;
+                      } else {
+                          exclude = false;
+                      }
+                  }
+                  if(xml.tokenType() == QXmlStreamReader::StartElement && xml.name() == "trkseg") {
+                      xml.readNext();
+                      qDebug() << "got track segment:" << xml.text();
+                      while(!(xml.tokenType() == QXmlStreamReader::EndElement && xml.name() == "trkseg")) {
+                          xml.readNext();
+                          if(xml.tokenType() == QXmlStreamReader::StartElement && xml.name() == "trkpt") {
+                              QGeoCoordinate coord;
+                              coord.setLongitude(xml.attributes().value("lon").toString().toDouble());
+                              coord.setLatitude(xml.attributes().value("lat").toString().toDouble());
+                              path.append(coord);
+                          }
+                      }
+                  }
+
+            }
+
+            Area area;
+            area.setPath(path);
+//            qDebug() << "appending path" << path;
+            if(!exclude) {
+                areaList.append(area);
+            } else {
+                excludeList.append(area);
+            }
+        }
+
+    }
+    m_businessArea.setAreaList(areaList);
+    m_businessArea.setExcludes(excludeList);
+}
