@@ -79,7 +79,7 @@ void MainWindow::initialize()
 
     // create Engine
     connect(Core::engine(), SIGNAL(downloadStarted()), SLOT(downloadStarted()));
-    connect(Core::engine(), SIGNAL(downloadFinished(bool , const QString &)), SLOT(downloadFinished(bool, const QString &)));
+    connect(Core::engine(), SIGNAL(downloadFinished(GMWItem::Type, bool , const QString &)), SLOT(downloadFinished(GMWItem::Type, bool, const QString &)));
     connect(Core::engine(), SIGNAL(loadedFromCache(GMWItem::Type,QDateTime)), SLOT(loadedFromCache(GMWItem::Type,QDateTime)));
 
     // Menubar
@@ -111,7 +111,7 @@ void MainWindow::initialize()
         m_gps->startUpdates();
     } else {
         qDebug() << "No GPS available";
-        //m_map->positionUpdated(QGeoPositionInfo(QGeoCoordinate(-27.5796, 153.1), QDateTime::currentDateTime()));
+        //positionUpdated(QGeoPositionInfo(QGeoCoordinate(48.41000, 9.96000), QDateTime::currentDateTime()));
     }
     connect(this, SIGNAL(positionUpdated(const QGeoCoordinate&, qreal)), Core::model(), SLOT(currentPositionChanged(const QGeoCoordinate&, qreal)));
     Core::map()->setTracking(true);
@@ -168,7 +168,12 @@ void MainWindow::timerEvent(QTimerEvent *event)
 
 void MainWindow::about() {
    QMessageBox::about(this, tr("Get Me Wheels - Car finder"),
-                      tr("Get Me Wheels - Car finder <br> Authors: <br>Christian Fetzer (fetzer.ch@googlemail.com) <br> Michael Zanetti (mzanetti@kde.org)"));
+                      tr("Get Me Wheels - Car finder <br> " \
+                         "Authors: <br>Christian Fetzer (fetzer.ch@googlemail.com) <br>" \
+                         "Michael Zanetti (mzanetti@kde.org) <br><br>" \
+                         "Helps you finding the fastest way to the next free car2go (This " \
+                         "product uses the car2go API but is not endorsed or certified by " \
+                         "car2go - www.car2go.com)."));
 }
 
 void MainWindow::createStatusBar() {
@@ -257,6 +262,7 @@ void MainWindow::loadSettings() {
         changed = true;
         Core::model()->clearAll();
         Core::engine()->setLocation(location);
+        Core::map()->setBusinessArea(Core::engine()->businessArea());
     }
 
     if(changed) {
@@ -335,7 +341,9 @@ void MainWindow::downloadStarted() {
     statusBarDownload->setText(tr("Downloading data..."));
 }
 
-void MainWindow::downloadFinished(bool success, const QString &errorString) {
+void MainWindow::downloadFinished(GMWItem::Type type, bool success, const QString &errorString) {
+    Q_UNUSED(type)
+    qDebug() << "download finished";
     if(success){
         statusBarDownload->setText(tr("Data download successful @ %1").arg(QDateTime::currentDateTime().toString("h:mm")));
     } else {
@@ -346,10 +354,17 @@ void MainWindow::downloadFinished(bool success, const QString &errorString) {
 void MainWindow::loadedFromCache(GMWItem::Type type, const QDateTime &cacheDate) {
     QString typeString;
     switch (type) {
-    case GMWItem::TypeVehicle: typeString = tr("Vehicles"); break;
-    case GMWItem::TypeGasStation: typeString = tr("Gas Stations"); break;
-    case GMWItem::TypeParkingLot: typeString = tr("Parking Lots"); break;
-    default: qWarning("Unknown data loaded from cache");
+    case GMWItem::TypeVehicle:
+        typeString = tr("Vehicles");
+        break;
+    case GMWItem::TypeGasStation:
+        typeString = tr("Gas Stations");
+        break;
+    case GMWItem::TypeParkingLot:
+        typeString = tr("Parking Lots");
+        break;
+    default:
+        qWarning("Unknown data loaded from cache");
     }
     qint64 age = cacheDate.msecsTo(QDateTime::currentDateTime()) / 1000;
     QString ageString;
