@@ -21,6 +21,7 @@
 #define GMWMAP_H
 
 #include "data/gmwitemsortfilterproxymodel.h"
+#include "data/gmwbusinessarea.h"
 
 #include <QtCore/QPointF>
 
@@ -62,6 +63,7 @@ public slots:
     virtual QStringList supportedMapProviders() const = 0;
     virtual QString mapProvider() const = 0;
     virtual bool setMapProvider(const QString &provider) = 0;
+    virtual void setBusinessArea(const GMWBusinessArea &area) = 0;
 
     void enableTracking();
     void disableTracking();
