@@ -21,7 +21,6 @@
 
 #include "geomap.h"
 #include "gmwmarker.h"
-#include "navigator.h"
 
 #include <QtCore/QDebug>
 #include <QtCore/QPropertyAnimation>
@@ -31,6 +30,8 @@
 
 #include <QtLocation/QGeoBoundingBox>
 #include <QtLocation/QGeoMapPolygonObject>
+#include <QtLocation/QGeoRoutingManager>
+#include <QtLocation/QGeoMapPolylineObject>
 
 /**
  * Private class ensures that map always fills view.
@@ -95,6 +96,9 @@ bool MobilityMap::setMapProvider(const QString &provider)
             delete m_serviceProvider;
         }
         m_serviceProvider = new QGeoServiceProvider(provider);
+        if(m_serviceProvider->routingManager()) {
+            m_serviceProvider->routingManager()->setLocale(QLocale("de"));
+        }
         m_providerName = provider;
         initialize();
         return true;
@@ -136,35 +140,58 @@ void MobilityMap::initialize()
     m_positionMarker->setZValue(1);
     map->addMapObject(m_positionMarker);
 
-    setRegion();
-
     rowsInserted(QModelIndex(), 0, m_model->rowCount() - 1);
 
+    QPen pen = m_routeObject.pen();
+    pen.setColor(Qt::red);
+
+    // See http://bugreports.qt.nokia.com/browse/QTMOBILITY-1655
+    pen.setWidth(3);
+
+    m_routeObject.setPen(pen);
+    m_map->addMapObject(&m_routeObject);
 }
 
-void MobilityMap::setRegion()
+void MobilityMap::setBusinessArea(const GMWBusinessArea &businessArea)
 {
-    QGeoMapPolygonObject *region = new QGeoMapPolygonObject();
-    QColor color(Qt::blue);
-    color.setAlpha(30);
-    QBrush brush(color);
-    region->setBrush(brush);
+    // clean old ones
+    while(!m_businessAreaList.isEmpty()) {
+        QGeoMapObject *obj = m_businessAreaList.takeFirst();
+        m_map->removeMapObject(obj);
+        delete obj;
+    }
 
     QPen pen(Qt::blue);
     pen.setWidth(5);
-    region->setPen(pen);
-    region->setPen(pen);
+    QColor color(Qt::blue);
+    color.setAlpha(30);
+    QBrush brush(color);
 
-    QList<QGeoCoordinate> path;
-    path.append(QGeoCoordinate(48.426698, 9.904337));
-    path.append(QGeoCoordinate(48.36949, 9.948518));
-    path.append(QGeoCoordinate(48.364419, 10.010472));
-    path.append(QGeoCoordinate(48.393634, 10.028695));
-    path.append(QGeoCoordinate(48.417814, 10.0047));
-    path.append(QGeoCoordinate(48.41738, 9.96521));
-    region->setPath(path);
-    region->setZValue(0);
-    m_map->addMapObject(region);
+    foreach(const Area &area, businessArea.areaList()) {
+        QGeoMapPolygonObject *region = new QGeoMapPolygonObject();
+        region->setBrush(brush);
+        region->setPen(pen);
+
+        region->setPath(area.path());
+        region->setZValue(0);
+        m_map->addMapObject(region);
+        m_businessAreaList.append(region);
+    }
+
+    color = QColor(Qt::red);
+    color.setAlpha(30);
+    brush.setColor(color);
+
+    foreach(const Area &area, businessArea.excludes()) {
+        QGeoMapPolygonObject *region = new QGeoMapPolygonObject();
+        region->setBrush(brush);
+        region->setPen(pen);
+
+        region->setPath(area.path());
+        region->setZValue(0);
+        m_map->addMapObject(region);
+        m_businessAreaList.append(region);
+    }
 }
 
 void MobilityMap::positionUpdated(const QGeoPositionInfo &info)
@@ -174,6 +201,12 @@ void MobilityMap::positionUpdated(const QGeoPositionInfo &info)
     }
     GMWMap::positionUpdated(info);
     m_positionMarker->setCoordinate(info.coordinate());
+
+    if(!m_routeObject.route().path().isEmpty()) {
+        if(m_routeObject.route().path().first().distanceTo(info.coordinate()) > 250) {
+            routeTo(m_routeObject.route().path().last());
+        }
+    }
 }
 
 void MobilityMap::moveTo(const QGeoCoordinate &point)
@@ -183,16 +216,40 @@ void MobilityMap::moveTo(const QGeoCoordinate &point)
 
 void MobilityMap::routeTo(const QGeoCoordinate &point)
 {
-    qDebug() << m_view->size();
-    //Navigator *navigator = new Navigator(m_serviceProvider->routingManager(), m_mapWidget, point);
-    //m_lastNavigator = navigator;
+    if(!m_serviceProvider->routingManager()) {
+        qDebug() << "Routing not supported by service provider";
+        return;
+    }
+    qDebug() << "routing from" << m_positionMarker->coordinate() << "to" << point;
 
-    //connect(navigator, SIGNAL(routingError(QGeoRouteReply::Error,QString)), this, SLOT(showErrorMessage(QGeoRouteReply::Error,QString)));
+    QGeoRouteRequest request;
+    request.setTravelModes(QGeoRouteRequest::PedestrianTravel);
+    request.setRouteOptimization(QGeoRouteRequest::ShortestRoute);
+    request.setWaypoints(QList<QGeoCoordinate>() << m_positionMarker->coordinate() << point);
 
-    //mapsWidget->statusBar()->setText("Routing...");
-    //mapsWidget->statusBar()->show();
+    m_serviceProvider->routingManager()->calculateRoute(request);
+    connect(m_serviceProvider->routingManager(), SIGNAL(finished(QGeoRouteReply*)), SLOT(routingFinished(QGeoRouteReply*)));
+    connect(m_serviceProvider->routingManager(), SIGNAL(error(QGeoRouteReply*,QGeoRouteReply::Error,QString)), SLOT(routingError(QGeoRouteReply*,QGeoRouteReply::Error,QString)));
+}
 
-    //navigator->start();
+void MobilityMap::routingFinished(QGeoRouteReply *reply)
+{
+    qDebug() << "Routing finished. Found" << reply->routes().count() << "routes";
+    if(reply->routes().count() <= 0) {
+        reply->deleteLater();
+        return;
+    }
+
+    m_map->removeMapObject(&m_routeObject);
+    m_routeObject.setRoute(reply->routes().first());
+    m_map->addMapObject(&m_routeObject);
+}
+
+void MobilityMap::routingError(QGeoRouteReply *reply, QGeoRouteReply::Error error, const QString &errorString)
+{
+    Q_UNUSED(error);
+    qDebug() << "Routing failed:" << errorString;
+    reply->deleteLater();
 }
 
 void MobilityMap::zoomIn()
@@ -247,7 +304,7 @@ void MobilityMap::rowsAboutToBeRemoved(const QModelIndex &parent, int start, int
 {
     Q_UNUSED(parent)
 
-    qDebug() << "Removing markers from map" << start << "-" << end << "Current markers:" << m_items.count() << "Markers to remove:" << end-start+1;
+//    qDebug() << "Removing markers from map" << start << "-" << end << "Current markers:" << m_items.count() << "Markers to remove:" << end-start+1;
     for(int i = start; i <= end; ++i) {
         QModelIndex index = m_model->index(i, 0);
         GMWItem *item = m_model->data(index, Qt::UserRole).value<GMWItem*>();
