@@ -29,6 +29,8 @@
 #include <QtLocation/QGeoPositionInfo>
 #include <QtLocation/QGraphicsGeoMap>
 #include <QtLocation/QGeoMapPixmapObject>
+#include <QtLocation/QGeoRouteReply>
+#include <QtLocation/QGeoMapRouteObject>
 
 QTM_USE_NAMESPACE
 
@@ -52,7 +54,7 @@ public slots:
     virtual void zoomOut();
     virtual void zoomTo(const QGeoBoundingBox &bounds);
     virtual void refresh();
-    virtual void setRegion();
+    virtual void setBusinessArea(const GMWBusinessArea &area);
 
     virtual QStringList supportedMapProviders() const;
     virtual QString mapProvider() const;
@@ -62,6 +64,8 @@ protected slots:
     virtual void rowsInserted(const QModelIndex &parent, int start, int end);
     virtual void rowsAboutToBeRemoved(const QModelIndex &parent, int start, int end);
 
+    void routingFinished(QGeoRouteReply *reply);
+    void routingError(QGeoRouteReply *reply, QGeoRouteReply::Error error, const QString &errorString);
 private:
     QGeoServiceProvider        *m_serviceProvider;
     QGeoMappingManager         *m_mappingManager;
@@ -70,6 +74,8 @@ private:
     QGeoMapPixmapObject        *m_positionMarker;
     MapView                    *m_view;
     QString                     m_providerName;
+    QList<QGeoMapObject*>       m_businessAreaList;
+    QGeoMapRouteObject          m_routeObject;
 
 private slots:
     void animatedPanTo(const QGeoCoordinate &center);
